@@ -1,44 +1,52 @@
-__all__ = ["voc", "VocXmlParser", "VocMaskParser"]
+__all__ = ["voc", "VOCBBoxParser", "VOCMaskParser"]
 
 import xml.etree.ElementTree as ET
 from icevision.imports import *
 from icevision.utils import *
 from icevision.core import *
 from icevision.parsers.parser import *
-from icevision.parsers.defaults import *
-from icevision.parsers.mixins import *
 
 
 def voc(
     annotations_dir: Union[str, Path],
     images_dir: Union[str, Path],
-    class_map: ClassMap,
+    class_map: Optional[ClassMap] = None,
     masks_dir: Optional[Union[str, Path]] = None,
+    idmap: Optional[IDMap] = None,
 ):
+    logger.warning(
+        "This function will be deprecated, instantiate the concrete "
+        "classes instead: `VOCBBoxParser`, `VOCMaskParser`"
+    )
     if not masks_dir:
-        return VocXmlParser(
+        return VOCBBoxParser(
             annotations_dir=annotations_dir,
             images_dir=images_dir,
             class_map=class_map,
+            idmap=idmap,
         )
     else:
-        return VocMaskParser(
+        return VOCMaskParser(
             annotations_dir=annotations_dir,
             images_dir=images_dir,
             masks_dir=masks_dir,
             class_map=class_map,
+            idmap=idmap,
         )
 
 
-class VocXmlParser(Parser, FilepathMixin, SizeMixin, LabelsMixin, BBoxesMixin):
+# TODO: Rename to VOCBBoxParser?
+class VOCBBoxParser(Parser):
     def __init__(
         self,
         annotations_dir: Union[str, Path],
         images_dir: Union[str, Path],
-        class_map: ClassMap,
+        class_map: Optional[ClassMap] = None,
+        idmap: Optional[IDMap] = None,
     ):
+        super().__init__(template_record=self.template_record(), idmap=idmap)
+        self.class_map = class_map or ClassMap().unlock()
         self.images_dir = Path(images_dir)
-        self.class_map = class_map
 
         self.annotations_dir = Path(annotations_dir)
         self.annotation_files = get_files(self.annotations_dir, extensions=[".xml"])
@@ -49,27 +57,46 @@ class VocXmlParser(Parser, FilepathMixin, SizeMixin, LabelsMixin, BBoxesMixin):
     def __iter__(self):
         yield from self.annotation_files
 
+    def template_record(self) -> BaseRecord:
+        return BaseRecord(
+            (
+                FilepathRecordComponent(),
+                InstancesLabelsRecordComponent(),
+                BBoxesRecordComponent(),
+            )
+        )
+
+    def record_id(self, o) -> Hashable:
+        return str(Path(self._filename).stem)
+
     def prepare(self, o):
         tree = ET.parse(str(o))
         self._root = tree.getroot()
         self._filename = self._root.find("filename").text
         self._size = self._root.find("size")
 
-    def imageid(self, o) -> Hashable:
-        return str(Path(self._filename).stem)
+    def parse_fields(self, o, record, is_new):
+        if is_new:
+            record.set_filepath(self.filepath(o))
+            record.set_img_size(self.img_size(o))
+
+        record.detection.set_class_map(self.class_map)
+        record.detection.add_labels(self.labels(o))
+        record.detection.add_bboxes(self.bboxes(o))
 
     def filepath(self, o) -> Union[str, Path]:
         return self.images_dir / self._filename
 
-    def image_width_height(self, o) -> Tuple[int, int]:
-        return get_image_size(self.filepath(o))
+    def img_size(self, o) -> ImgSize:
+        width = int(self._size.find("width").text)
+        height = int(self._size.find("height").text)
+        return ImgSize(width=width, height=height)
 
-    def labels(self, o) -> List[int]:
+    def labels(self, o) -> List[Hashable]:
         labels = []
         for object in self._root.iter("object"):
             label = object.find("name").text
-            label_id = self.class_map.get_name(label)
-            labels.append(label_id)
+            labels.append(label)
 
         return labels
 
@@ -91,28 +118,32 @@ class VocXmlParser(Parser, FilepathMixin, SizeMixin, LabelsMixin, BBoxesMixin):
         return bboxes
 
 
-class VocMaskParser(VocXmlParser, MasksMixin):
+class VOCMaskParser(VOCBBoxParser):
     def __init__(
         self,
         annotations_dir: Union[str, Path],
         images_dir: Union[str, Path],
         masks_dir: Union[str, Path],
-        class_map: ClassMap,
+        class_map: Optional[ClassMap] = None,
+        idmap: Optional[IDMap] = None,
     ):
         super().__init__(
-            annotations_dir=annotations_dir, images_dir=images_dir, class_map=class_map
+            annotations_dir=annotations_dir,
+            images_dir=images_dir,
+            class_map=class_map,
+            idmap=idmap,
         )
         self.masks_dir = masks_dir
         self.mask_files = get_image_files(masks_dir)
 
-        self._imageid2maskfile = {self.imageid_mask(o): o for o in self.mask_files}
+        self._record_id2maskfile = {self.record_id_mask(o): o for o in self.mask_files}
 
         # filter annotations
-        masks_ids = frozenset(self._imageid2maskfile.keys())
+        masks_ids = frozenset(self._record_id2maskfile.keys())
         self._intersection = []
         for item in super().__iter__():
             super().prepare(item)
-            if super().imageid(item) in masks_ids:
+            if super().record_id(item) in masks_ids:
                 self._intersection.append(item)
 
     def __len__(self):
@@ -121,10 +152,19 @@ class VocMaskParser(VocXmlParser, MasksMixin):
     def __iter__(self):
         yield from self._intersection
 
-    def imageid_mask(self, o) -> Hashable:
-        """Should return the same as `imageid` from parent parser."""
+    def template_record(self) -> BaseRecord:
+        record = super().template_record()
+        record.add_component(MasksRecordComponent())
+        return record
+
+    def record_id_mask(self, o) -> Hashable:
+        """Should return the same as `record_id` from parent parser."""
         return str(Path(o).stem)
 
+    def parse_fields(self, o, record, is_new):
+        super().parse_fields(o, record, is_new=is_new)
+        record.detection.add_masks(self.masks(o))
+
     def masks(self, o) -> List[Mask]:
-        mask_file = self._imageid2maskfile[self.imageid(o)]
+        mask_file = self._record_id2maskfile[self.record_id(o)]
         return [VocMaskFile(mask_file)]
