@@ -26,6 +26,7 @@ def show_sample(
     show: bool = True,
     ax: plt.Axes = None,
     figsize: Tuple[int, int] = None,
+    **draw_sample_kwargs,
 ) -> None:
     img = draw_sample(
         sample=sample,
@@ -35,6 +36,7 @@ def show_sample(
         display_bbox=display_bbox,
         display_mask=display_mask,
         display_keypoints=display_keypoints,
+        **draw_sample_kwargs,
     )
     show_img(img=img, ax=ax, show=show, figsize=figsize)
 
@@ -49,6 +51,7 @@ def show_record(
     ax: plt.Axes = None,
     show: bool = False,
     figsize: Tuple[int, int] = None,
+    **draw_sample_kwargs,
 ) -> None:
     img = draw_record(
         record=record,
@@ -57,31 +60,64 @@ def show_record(
         display_bbox=display_bbox,
         display_mask=display_mask,
         display_keypoints=display_keypoints,
+        **draw_sample_kwargs,
     )
     show_img(img=img, ax=ax, show=show, figsize=figsize)
 
 
 def show_pred(
-    img: np.ndarray,
-    pred: dict,
-    class_map: Optional[ClassMap] = None,
+    pred: Prediction,
     denormalize_fn: Optional[callable] = denormalize_imagenet,
     display_label: bool = True,
     display_bbox: bool = True,
     display_mask: bool = True,
     show: bool = True,
     ax: plt.Axes = None,
+    figsize=None,
+    annotation=None,
+    **draw_sample_kwargs,
 ) -> None:
-    img = draw_pred(
-        img=img,
+    actual = draw_sample(
+        sample=pred.ground_truth,
+        display_label=display_label,
+        display_bbox=display_bbox,
+        display_mask=display_mask,
+        denormalize_fn=denormalize_fn,
+    )
+
+    prediction = draw_pred(
         pred=pred,
-        class_map=class_map,
         denormalize_fn=denormalize_fn,
         display_label=display_label,
         display_bbox=display_bbox,
         display_mask=display_mask,
+        **draw_sample_kwargs,
     )
-    show_img(img=img, ax=ax, show=show)
+
+    if ax is None:
+        fig, ax = plt.subplots(1, 2, figsize=figsize)
+
+    ax[0].imshow(actual, cmap=None)
+    ax[0].set_title("Ground truth")
+    ax[1].imshow(prediction, cmap=None)
+    ax[1].set_title("Prediction")
+
+    if annotation is None:
+        ax[0].set_axis_off()
+        ax[1].set_axis_off()
+    else:
+        ax[0].get_xaxis().set_ticks([])
+        ax[0].set_frame_on(False)
+        ax[0].get_yaxis().set_visible(False)
+        ax[0].set_xlabel(annotation[0], ma="left")
+
+        ax[1].get_xaxis().set_ticks([])
+        ax[1].set_frame_on(False)
+        ax[1].get_yaxis().set_visible(False)
+        ax[1].set_xlabel(annotation[1], ma="left")
+
+    if show:
+        plt.show()
 
 
 def show_records(
@@ -93,6 +129,7 @@ def show_records(
     ncols: int = 1,
     figsize=None,
     show: bool = False,
+    **draw_sample_kwargs,
 ) -> None:
     partials = [
         partial(
@@ -103,6 +140,7 @@ def show_records(
             display_mask=display_mask,
             class_map=class_map,
             show=False,
+            **draw_sample_kwargs,
         )
         for record in records
     ]
@@ -119,6 +157,7 @@ def show_samples(
     ncols: int = 1,
     figsize=None,
     show=False,
+    **draw_sample_kwargs,
 ) -> None:
     partials = [
         partial(
@@ -130,6 +169,7 @@ def show_samples(
             display_mask=display_mask,
             class_map=class_map,
             show=False,
+            **draw_sample_kwargs,
         )
         for sample in samples
     ]
@@ -137,70 +177,37 @@ def show_samples(
 
 
 def show_preds(
-    samples: Union[Sequence[np.ndarray], Sequence[dict]],
-    preds: Sequence[dict],
-    class_map: Optional[ClassMap] = None,
+    preds: Sequence[Prediction],
     denormalize_fn: Optional[callable] = denormalize_imagenet,
     display_label: bool = True,
     display_bbox: bool = True,
     display_mask: bool = True,
-    ncols: int = 1,
     figsize=None,
     show=False,
     annotations=None,
+    ncols=None,  # TODO: Not used,
+    **draw_sample_kwargs,
 ) -> None:
-    if not len(samples) == len(preds):
-        raise ValueError(
-            f"Number of imgs ({len(samples)}) should be the same as "
-            f"the number of preds ({len(preds)})"
+    annotations = annotations or [None] * len(preds)
+    partials = [
+        partial(
+            show_pred,
+            pred=pred,
+            denormalize_fn=denormalize_fn,
+            display_label=display_label,
+            display_bbox=display_bbox,
+            display_mask=display_mask,
+            show=False,
+            annotation=annotation,
+            **draw_sample_kwargs,
         )
+        for pred, annotation in zip(preds, annotations)
+    ]
 
-    if all(type(x) is dict for x in samples):
-        actuals = [
-            draw_sample(
-                sample=sample,
-                class_map=class_map,
-                display_label=display_label,
-                display_bbox=display_bbox,
-                display_mask=display_mask,
-                denormalize_fn=denormalize_fn,
-            )
-            for sample in samples
-        ]
-
-        imgs = [sample["img"] for sample in samples]
-        predictions = [
-            draw_pred(
-                img=img,
-                pred=pred,
-                class_map=class_map,
-                denormalize_fn=denormalize_fn,
-                display_label=display_label,
-                display_bbox=display_bbox,
-                display_mask=display_mask,
-            )
-            for img, pred in zip(imgs, preds)
-        ]
-
-        plot_grid_preds_actuals(
-            actuals, predictions, figsize=figsize, show=show, annotations=annotations
-        )
-
-    else:
-        partials = [
-            partial(
-                show_pred,
-                img=img,
-                pred=pred,
-                class_map=class_map,
-                denormalize_fn=denormalize_fn,
-                display_label=display_label,
-                display_bbox=display_bbox,
-                display_mask=display_mask,
-                show=False,
-            )
-            for img, pred in zip(samples, preds)
-        ]
-        plot_grid(
-            partials, ncols=ncols, figsize=figsize, show=show, annotations=annotations
-        )
+    plot_grid(
+        partials,
+        ncols=2,
+        figsize=figsize or (6, 6 * len(preds) / 2 / 0.75),
+        show=show,
+        axs_per_iter=2,
+    )
